@@ -9,16 +9,23 @@ class DataSource(ABC):
         pass
 
     @abstractmethod
-    def get(self):
+    def description(self):
         pass
 
-    def get_cached(self):
+    @abstractmethod
+    def get_direct(self):
+        pass
+
+    def get(self):
+        print(self.description())
         return get(self)
 
 
 @permacache(
     "electiondata/data_source/get",
-    key_function=dict(source=lambda source: [source.version(), type(source).__name__]),
+    key_function=dict(
+        source=lambda source: [source.version(), type(source).__name__, source.__dict__]
+    ),
 )
 def get(source):
-    return source.get()
+    return source.get_direct()
